declare type SecurityAgent<T> = T | Promise<T> | undefined | Promise<undefined>;
declare type Scope<T> = (retrived: T, scopes: string[]) => boolean | Promise<boolean>;
declare type ValidateScope = (scope: string) => boolean;
export declare type OAS2_SecurityType = OAS2_BasicAuth | ApiKeyAuth;
export declare type OAS3_SecurityType = OAS3_BasicAuth | ApiKeyAuth | BearerAuth | OpenIdConnectAuth;
export declare type SecurityTypes = BasicAuth | ApiKeyAuth | BearerAuth | OpenIdConnectAuth;
export declare type StrictSecurity<T> = StrictBasicAuthSecurity<T> | StrictApiKeySecurity<T> | StrictBearerSecurity<T> | StrictOpenIdConnectSecurity<T>;
export declare type BasicAuth = OAS2_BasicAuth | OAS3_BasicAuth;
export interface OAS2_BasicAuth {
    type: 'basic';
    description?: string;
}
export interface OAS3_BasicAuth {
    type: 'http';
    scheme: 'basic';
    description?: string;
}
export interface StrictBasicAuthSecurity<T extends unknown> {
    security: BasicAuth;
    handle: (username: string, password: string) => SecurityAgent<T>;
    scopes: Scope<T>;
    validScopes?: string[];
    validateScope?: ValidateScope;
}
export interface ApiKeyAuth {
    type: 'apiKey';
    in: 'header' | 'query';
    name: string;
    description?: string;
}
export interface StrictApiKeySecurity<T extends unknown> {
    security: ApiKeyAuth;
    handle: (apikey: string) => SecurityAgent<T>;
    scopes: Scope<T>;
    validScopes?: string[];
    validateScope?: ValidateScope;
}
export interface BearerAuth {
    type: 'http';
    scheme: 'bearer';
    description?: string;
}
export interface StrictBearerSecurity<T extends unknown> {
    security: BearerAuth;
    handle: (token: string) => SecurityAgent<T>;
    scopes: Scope<T>;
    validScopes?: string[];
    validateScope?: ValidateScope;
}
export interface OpenIdConnectAuth {
    type: 'openIdConnect';
    openIdConnectUrl: string;
    description?: string;
}
export interface StrictOpenIdConnectSecurity<T extends unknown> {
    security: OpenIdConnectAuth;
    handle: (token: string) => SecurityAgent<T>;
    scopes: Scope<T>;
    validScopes?: string[];
    validateScope?: ValidateScope;
}
export {};
//# sourceMappingURL=types.d.ts.map